<template>
    <div class="report-overview">
        <div class="left-content">
            <div class="group-list">
                <div class="list-header">
                    <div style="width: 100%">获奖分类</div>
                    <!-- <div style="width: 50%">获奖次数</div> -->
                </div>
                <div :class="['list-item', params.querys[1].value === item.value ? 'active-item' : '']"
                    v-for="(item, index) in prizeClassify" :key="index" @click="listItemClick(item)">
                    <div style="width: 100%">{{ item.name }}</div>
                    <!-- <div style="width: 40%">{{ item.nationwideNum }}</div> -->
                </div>
            </div>
        </div>
        <div class="right-content">
            <el-row :gutter="12">
                <el-col :span="6">
                    <div class="search-label">文件名称：</div>
                    <el-input v-model="params.querys[0].value" clearable suffix-icon="el-icon-search"
                        placeholder="请输入资料名称" style="width: 100%"></el-input>
                </el-col>
                <el-col class="search-btn" :span="2">
                    <div class="search-label"></div>
                    <el-button class="download" type="primary" icon="el-icon-search" @click="getData(1)">查询</el-button>
                </el-col>
            </el-row>
            <div class="content-box">
                <div class="right-table">
                    <el-table height="calc(100% - 30px)" ref="dataTable" :data="tableData" id="table-bigger-detail"
                        :element-loading-background="loadingColor" v-loading="tableLoading" class="dialog_table" border
                        style="width: 100%" :header-cell-style="{ 'text-align': 'center' }">
                        <el-table-column type="index" label="序号" align="center" width="100">
                        </el-table-column>
                        <el-table-column prop="profileName" label="文件名称">
                        </el-table-column>
                        <el-table-column label="获奖分类" align="center" width="200">
                            <template v-slot="{ row }">
                                {{ getDictName('hjfl', row.profileInnovationClassify+'') }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="profileName" label="操作" align="center" width="220">
                            <template v-slot="{ row }">
                                <FileList :fileList="[row]"></FileList>
                            </template>
                        </el-table-column>
                    </el-table>
                    <pagenation class="pagenation" @currentChange="pageChange" :pageResult="params.pageBean">
                    </pagenation>
                </div>
            </div>
        </div>
    </div>
</template>

<script>
import FileList from '@/components/uploadFile/newFileList.vue'
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/majorView.js'
import utils from '@/utils.js'
export default {
    name: 'reformDataBase',
    components: {
        pagenation,
        FileList,
    },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableLoading: false,
            fileLoading: false,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'file_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'profile_Innovation_Classify_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'profile_Type_',
                        relation: 'AND',
                        value: '2',
                    },
                ],
                sorter: []
            },
            tableData: [],
            dataList: [],
            prizeClassify: []
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.getData(1)
    },
    created() {
        this.prizeClassify = utils.getDictItemsFromCache('hjfl')
        this.prizeClassify.unshift({value:'',name: '所有分类'})
        this.$emit('searchDateChange')
    },
    methods: {
        listItemClick({value}) {
            this.params.querys[1].value = value
            this.getData(1)
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        getData(page) {
            this.tableLoading = true
            this.params.pageBean.page = page
            this.tableData = []
            apiList.getReformDataBase(this.params, res => {
                this.params.pageBean.total = res.total
                this.tableData = res.rows
                this.tableLoading = false
            })
        },
        pageChange(key) {
            this.getData(key)
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/.file-item {
    border: none;
    justify-content: center;

    .file_name {
        display: none;
    }

    a {
        .el-link--inner {
            font-size: 19PX !important;
        }
    }

    &:hover {
        background: none;
        color: #fff;

        .file_name {
            color: #fff;
        }
    }
}

/deep/.el-collapse {
    border: none;
}

/deep/.el-collapse-item__wrap {
    background: transparent;
    border: none;
}

/deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
    border-color: #245cf3;
    background: transparent;
    color: #fff;
    font-size: 20PX;
}

/deep/.el-table td.el-table__cell div {
    // background: transparent;
}

/deep/.el-table--enable-row-hover .el-table__body tr:hover>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}

/deep/.dialog_table.el-table tr:nth-of-type(2n + 1) {
    background: transparent;
}

/deep/.el-descriptions__body {
    background: transparent;
}

/deep/.el-collapse-item__header.is-active {
    border-bottom-color: transparent;
    background: transparent;
    color: #245cf3;
    font-size: 20px;
    font-weight: bold;
}

/deep/.el-collapse-item__header {
    background: transparent;
    color: #245cf3;
    font-size: 20PX !important;
    font-weight: bold;
    border: none;
}

/deep/.el-collapse-item__arrow {
    margin: 0;
    font-weight: bold;
}

/deep/.dialog-table-expand label {
    width: 120px;
    color: #fff;
    font-family: SimHei;
}

/deep/.el-table__body tr.current-row>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}

/deep/.el-table {
    background: transparent;
    border: 1px solid rgba(2, 115, 233, 0.5);
    margin-bottom: 10PX;
}

/deep/.el-table th.el-table__cell.is-leaf,
/deep/.el-table td.el-table__cell {
    border-bottom: 1px solid #245cf3;
}

/deep/.el-table--border th {
    &:nth-last-child(2) {
        border-right: none !important;
    }
}
/deep/.el-table--border th,
/deep/.el-table--border td {
    border-right: 1px solid #245cf3 !important;

    &:nth-child(5) {
        border-right: none !important;
    }

    * {
        font-size: 20PX !important;
    }
}

/deep/.el-table--border::after,
/deep/.el-table::before {
    width: 0;
    height: 0;
}

/deep/.el-table tr,
/deep/.el-table thead tr,
/deep/.el-table thead tr th {
    background: transparent !important;
}

/deep/.el-table th.el-table__cell>.cell,
/deep/.el-table td>.cell {
    font-size: 18PX !important;
    color: #fff;
}

/deep/.el-table {
    background: transparent;
    border: 1px solid rgba(2, 115, 233, 0.5);
    margin-bottom: 10px;

    ::-webkit-scrollbar-thumb {
        background-color: #034eb0 !important;
    }

    ::-webkit-scrollbar-track {
        background: #01215a !important;
    }

    ::-webkit-scrollbar {
        width: 18px !important;
        background: #01215a !important;
    }
}

/deep/.el-table th.gutter {
    border: none !important;
    border-bottom: 1px solid #245cf3 !important;
    // background: transparent !important;
}
</style>
<style lang="scss" scoped>
.report-overview {
    display: flex;
    height: 100%;
    margin-top: 5PX;
    gap: 10PX;
    box-sizing: border-box;

    .left-content {
        width: 15%;
        height: 100%;
        border: 1px solid #245cf3;
        border-radius: 2PX;

        .list-header {
            display: flex;
            width: 100%;
            text-align: center;
            height: 50PX;
            line-height: 50PX;
            // color: #3399FF;
            background: linear-gradient(180deg, rgba(3, 62, 139, 0) 0%, #033E8B 100%);
            border-image: linear-gradient(90deg, rgba(51.00000075995922, 153.00000607967377, 255, 0), rgba(178.49999696016312, 216.75006687641144, 255, 0.20000000298023224), rgba(51.00000075995922, 153.00000607967377, 255, 0)) 1 1;

            >div {
                font-weight: bold;
                font-size: 19PX;
            }
        }

        .list-item {
            display: flex;
            width: 100%;
            text-align: center;
            align-items: center;
            height: 50PX;
            padding: 0 5PX;
            box-sizing: border-box;
            // line-height: 50PX;

            >div {
                font-size: 20PX;

                &:nth-child(2),
                &:nth-child(3) {
                    font-weight: bold;
                    color: #00D5FF;
                }
            }

            &:nth-child(2n+1) {
                background: #043072;
            }

            &:hover {
                cursor: pointer;
                background: #225092;
            }
        }

        .active-item {
            background: #225092 !important;
        }
    }

    .right-content {
        width: 75%;
        height: 100%;

        >.el-row {
            height: 60PX;
            margin-bottom: 20PX;

            .search-label {
                height: 20PX;
                font-size: 18PX;
                line-height: 20PX;
                margin-bottom: 5px;
            }

            .search-btn {
                /deep/.el-button {
                    height: 40PX;

                    >* {
                        font-size: 18PX;
                    }
                }
            }

            /deep/.el-input__inner {
                color: #fff;
                font-size: 18PX;
                height: 40PX;
                box-sizing: border-box;
                background: transparent;
                border: 1px solid #114385;

                &::placeholder {
                    color: #fff;
                    font-size: 18PX !important;
                }

                &::-webkit-input-placeholder {
                    font-size: 18PX !important;
                }
            }
        }

        .content-box {
            height: calc(100% - 80PX);
            display: flex;
            gap: 10PX;

            .right-table {
                width: 100%;
                height: 100%;
            }
        }
    }

    /deep/ .el-select-dropdown__item {
        background-color: #0d57ac !important;
        color: rgba(230, 247, 255, 0.7);

        span {
            font-size: 14px;
        }
    }

    /deep/ .el-select-dropdown__list {
        padding: 0;
    }

    /deep/ .el-select-dropdown {
        border: solid 1px #0273e9;
        background-color: rgba(1, 47, 115, 0.6);
    }

    /deep/.el-select-dropdown__item.hover,
    /deep/ .el-select-dropdown__item:hover {
        background-color: #025ec0 !important;
    }

    /deep/.el-popper[x-placement^="bottom"] .popper__arrow::after {
        border-bottom-color: #0d57ac;
    }

    /deep/.el-popper[x-placement^="bottom"] .popper__arrow {
        border-bottom-color: #0273e9;
    }
}
</style>
